@@ -38,6 +38,12 @@ density.dist_inverse_exponential <- function(x, at, ...){
   actuar::dinvexp(at, x[["r"]])
 }
 
+#' @export
+log_density.dist_inverse_exponential <- function(x, at, ...){
+  require_package("actuar")
+  actuar::dinvexp(at, x[["r"]], log = TRUE)
+}
+
 #' @export
 quantile.dist_inverse_exponential <- function(x, p, ...){
   require_package("actuar")
