@@ -34,23 +34,31 @@ format.dist_sample <- function(x, ...){
   )
 }
 
-# #' @export
-# density.dist_sample <- function(x, at, ...){
-# }
-#
+#' @export
+density.dist_sample <- function(x, at, ...){
+  d <- density(x[["x"]], from = min(at), to = max(at))
+  stats::approx(d$x, d$y, xout = at)$y
+}
+
 
 #' @export
 quantile.dist_sample <- function(x, p, ..., na.rm = TRUE){
+  if(length(p) > 1) return(vapply(p, quantile, numeric(1L), x = x, ...))
   vapply(x, quantile, numeric(1L), probs = p, ..., na.rm = na.rm, USE.NAMES = FALSE)
 }
 
-# #' @export
-# cdf.dist_sample <- function(x, q, ...){
-# }
-#
-# #' @export
-# generate.dist_sample <- function(x, times, ...){
-# }
+#' @export
+cdf.dist_sample <- function(x, q, ...){
+  if(length(q) > 1) return(vapply(q, cdf, numeric(1L), x = x, ...))
+  vapply(x, function(x, q){
+    mean(x < q)
+  }, numeric(1L), q = q)
+}
+
+#' @export
+generate.dist_sample <- function(x, times, ...){
+  sample(x[["x"]], size = times, replace = TRUE)
+}
 
 #' @export
 mean.dist_sample <- function(x, ...){
@@ -61,3 +69,13 @@ mean.dist_sample <- function(x, ...){
 variance.dist_sample <- function(x, ...){
   vapply(x, stats::var, numeric(1L), ..., USE.NAMES = FALSE)
 }
+
+#' @export
+skewness.dist_sample <- function(x, ...) {
+  n <- lengths(x, use.names = FALSE)
+  x <- lapply(x, function(.) . - mean(.))
+  sum_x2 <- vapply(x, function(.) sum(.^2), numeric(1L), USE.NAMES = FALSE)
+  sum_x3 <- vapply(x, function(.) sum(.^3), numeric(1L), USE.NAMES = FALSE)
+  y <- sqrt(n) * sum_x3/(sum_x2^(3/2))
+  y * ((1 - 1/n))^(3/2)
+}
