@@ -135,7 +135,13 @@ vec_arith.numeric.hilo <- function(op, x, y, ...){
 
 #' @export
 `$.hilo` <- function(x, name){
-  vec_data(x)[[name]]
+  field(x, name)
+}
+
+#' @export
+`names<-.hilo` <- function(x, value) {
+  # abort("A <hilo> object cannot be named.")
+  x
 }
 
 # Graphics ---------------------------------------------------------------------
